@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.42.2.2 2003/03/03 11:59:25 joern Exp $
+# $Id: Config.pm,v 1.42.2.3 2003/03/03 18:30:41 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -19,8 +19,6 @@ use FileHandle;
 use Data::Dumper;
 use Carp;
 
-my $DEFAULT_FILENAME = "$ENV{HOME}/.dvdriprc";
-
 sub config			{ shift->{config}			}
 
 sub order			{ shift->{order}			}
@@ -480,7 +478,8 @@ sub new {
 sub load {
 	my $self = shift;
 	
-	my $filename = $self->filename || $DEFAULT_FILENAME;
+	my $filename = $self->filename;
+	die "filename not set" if $filename eq '';
 	die "can't read $filename" if not -r $filename;
 	
 	my $loaded;
@@ -527,14 +526,15 @@ sub get_save_data {
 sub save {
 	my $self = shift; $self->trace_in;
 	
-	my $filename = $self->filename || $DEFAULT_FILENAME;
-	
+	my $filename = $self->filename;
+	die "filename not set" if $filename eq '';
+
 	my $data_sref = $self->get_save_data;
 	
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.42.2.2 2003/03/03 11:59:25 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.42.2.3 2003/03/03 18:30:41 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
